==> jc-1.4.0.tar.gz: javax/swing/plaf/DesktopPaneUI.h <==
// public abstract class javax.swing.plaf.DesktopPaneUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class 3e80551f3136bf5f javax_swing_plaf_DesktopPaneUI

// header file dependencies
// @dep_header javax_swing_plaf_ComponentUI

#include "javax/swing/plaf/ComponentUI.h"

#ifndef _JC_javax_swing_plaf_DesktopPaneUI_H_
#define _JC_javax_swing_plaf_DesktopPaneUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_DesktopPaneUI$sub_refs	_jc_javax_swing_plaf_DesktopPaneUI$sub_refs;
typedef struct _jc_javax_swing_plaf_DesktopPaneUI$sub_nonrefs	_jc_javax_swing_plaf_DesktopPaneUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_DesktopPaneUI$refs	_jc_javax_swing_plaf_DesktopPaneUI$refs;
typedef struct _jc_javax_swing_plaf_DesktopPaneUI$nonrefs	_jc_javax_swing_plaf_DesktopPaneUI$nonrefs;
typedef struct _jc_javax_swing_plaf_DesktopPaneUI$object	_jc_javax_swing_plaf_DesktopPaneUI$object;

typedef const struct _jc_javax_swing_plaf_DesktopPaneUI$vmethods	_jc_javax_swing_plaf_DesktopPaneUI$vmethods;
typedef const struct _jc_javax_swing_plaf_DesktopPaneUI$vtable	_jc_javax_swing_plaf_DesktopPaneUI$vtable;
typedef const struct _jc_javax_swing_plaf_DesktopPaneUI$vtype	_jc_javax_swing_plaf_DesktopPaneUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_DesktopPaneUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_DesktopPaneUI$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_DesktopPaneUI$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_DesktopPaneUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_DesktopPaneUI$vmethods	javax_swing_plaf_DesktopPaneUI;
};

// Vtype
struct _jc_javax_swing_plaf_DesktopPaneUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_DesktopPaneUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_DesktopPaneUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_DesktopPaneUI$refs {
    _jc_javax_swing_plaf_DesktopPaneUI$sub_refs	javax_swing_plaf_DesktopPaneUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_DesktopPaneUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_DesktopPaneUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_DesktopPaneUI$sub_nonrefs	javax_swing_plaf_DesktopPaneUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_DesktopPaneUI$object {
	_jc_javax_swing_plaf_DesktopPaneUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_DesktopPaneUI$vtype	*vtype;
	_jc_javax_swing_plaf_DesktopPaneUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_DesktopPaneUI$vtype _jc_javax_swing_plaf_DesktopPaneUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_DesktopPaneUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_DesktopPaneUI$class_object;

#endif	/* _JC_javax_swing_plaf_DesktopPaneUI_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/DesktopPaneUI.h <==
// public abstract class javax.swing.plaf.DesktopPaneUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class 3e80551f3136bf5f javax_swing_plaf_DesktopPaneUI

// header file dependencies
// @dep_header javax_swing_plaf_ComponentUI

#include "javax/swing/plaf/ComponentUI.h"

#ifndef _JC_javax_swing_plaf_DesktopPaneUI_H_
#define _JC_javax_swing_plaf_DesktopPaneUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_DesktopPaneUI$sub_refs	_jc_javax_swing_plaf_DesktopPaneUI$sub_refs;
typedef struct _jc_javax_swing_plaf_DesktopPaneUI$sub_nonrefs	_jc_javax_swing_plaf_DesktopPaneUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_DesktopPaneUI$refs	_jc_javax_swing_plaf_DesktopPaneUI$refs;
typedef struct _jc_javax_swing_plaf_DesktopPaneUI$nonrefs	_jc_javax_swing_plaf_DesktopPaneUI$nonrefs;
typedef struct _jc_javax_swing_plaf_DesktopPaneUI$object	_jc_javax_swing_plaf_DesktopPaneUI$object;

typedef const struct _jc_javax_swing_plaf_DesktopPaneUI$vmethods	_jc_javax_swing_plaf_DesktopPaneUI$vmethods;
typedef const struct _jc_javax_swing_plaf_DesktopPaneUI$vtable	_jc_javax_swing_plaf_DesktopPaneUI$vtable;
typedef const struct _jc_javax_swing_plaf_DesktopPaneUI$vtype	_jc_javax_swing_plaf_DesktopPaneUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_DesktopPaneUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_DesktopPaneUI$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_DesktopPaneUI$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_DesktopPaneUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_DesktopPaneUI$vmethods	javax_swing_plaf_DesktopPaneUI;
};

// Vtype
struct _jc_javax_swing_plaf_DesktopPaneUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_DesktopPaneUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_DesktopPaneUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_DesktopPaneUI$refs {
    _jc_javax_swing_plaf_DesktopPaneUI$sub_refs	javax_swing_plaf_DesktopPaneUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_DesktopPaneUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_DesktopPaneUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_DesktopPaneUI$sub_nonrefs	javax_swing_plaf_DesktopPaneUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_DesktopPaneUI$object {
	_jc_javax_swing_plaf_DesktopPaneUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_DesktopPaneUI$vtype	*vtype;
	_jc_javax_swing_plaf_DesktopPaneUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_DesktopPaneUI$vtype _jc_javax_swing_plaf_DesktopPaneUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_DesktopPaneUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_DesktopPaneUI$class_object;

#endif	/* _JC_javax_swing_plaf_DesktopPaneUI_H_ */
